@@ -1,6 +1,10 @@
 from __future__ import annotations
 
 
+class DistinctIndicesError(ValueError):
+    """Raised when there is no unique index."""
+
+
 class InvalidDTypeError(ValueError):
     """Raised when the dtype is invalid."""
 
@@ -9,6 +13,10 @@ class InvalidMinFracError(ValueError):
     """Raised when the minimum fraction is invalid."""
 
 
+class InvalidLagError(ValueError):
+    """Raised when the lag is invalid."""
+
+
 class InvalidLengthError(ValueError):
     """Raised when the length is invalid."""
 
@@ -23,3 +31,7 @@ class InvalidWindowError(ValueError):
 
 class NoSlicersError(ValueError):
     """Raised when no slicers are valid."""
+
+
+class NoWindowButMinFracProvidedError(ValueError):
+    """Raised when no window is provided but a minimum fraction is provided."""
